@@ -18,6 +18,7 @@ from unittest import mock
 
 import arviz as az
 import jax
+import jax.numpy as jnp
 import numpy as np
 import pytensor
 import pytensor.tensor as pt
@@ -29,6 +30,7 @@ from pytensor.graph import graph_inputs
 
 import pymc as pm
 
+from pymc.distributions.multivariate import PosDefMatrix
 from pymc.sampling.jax import (
     _get_batched_jittered_initial_points,
     _get_log_likelihood,
@@ -49,6 +51,25 @@ def test_old_import_route():
     assert set(new_sj.__all__) <= set(dir(old_sj))
 
 
+def test_jax_PosDefMatrix():
+    x = pt.tensor(name="x", shape=(2, 2), dtype="float32")
+    matrix_pos_def = PosDefMatrix()
+    x_is_pos_def = matrix_pos_def(x)
+    f = pytensor.function(inputs=[x], outputs=[x_is_pos_def], mode="JAX")
+
+    test_cases = [
+        (jnp.eye(2), True),
+        (jnp.zeros(shape=(2, 2)), False),
+        (jnp.array([[1, -1.5], [0, 1.2]], dtype="float32"), True),
+        (-1 * jnp.array([[1, -1.5], [0, 1.2]], dtype="float32"), False),
+        (jnp.array([[1, -1.5], [0, -1.2]], dtype="float32"), False),
+    ]
+
+    for input, expected in test_cases:
+        actual = f(input)[0]
+        assert jnp.array_equal(a1=actual, a2=expected)
+
+
 @pytest.mark.parametrize(
     "sampler",
     [
